# -*- coding: utf-8 -*-
"""
Django settings for dic-quo project.

Generated by 'django-admin startproject' using Django 3.1.1.

For more information on this file, see
https://docs.djangoproject.com/en/3.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.1/ref/settings/
"""

#  Copyright (c) 2020. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.

import socket
from dicquo.my_secret import *
from pathlib import Path

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = MY_SECRET_KEY

# SECURITY WARNING: don't run with debug turned on in production!
if socket.gethostname() in [MY_HOST_HOME, MY_HOST_WORK]:
    DEBUG = True
else:
    # Все остальные хосты (подразумевается продакшн)
    DEBUG = False

ALLOWED_HOSTS = [
    '127.0.0.1',
    'localhost',
    'dq.cube2.ru',  # Dreamhost HOSTNAME
]

#########################################
# Настройки сообщений об ошибках когда все упало и т.п.
ADMINS = (
    ('Sergey Erjemin', MY_EMAIL),
)

#########################################
# настройки для почтового сервера
EMAIL_HOST = 'smtp.mail.ru'                     # SMTP server
EMAIL_PORT = 2525                               # для SSL/https
EMAIL_HOST_USER = MY_EMAIL_HOST_USER            # login or ''
EMAIL_HOST_PASSWORD = MY_EMAIL_HOST_PASSWORD    # password
SERVER_EMAIL = DEFAULT_FROM_EMAIL = EMAIL_HOST_USER
EMAIL_USE_TLS = True
EMAIL_SUBJECT_PREFIX = '[DIC-QUO ERR]: '  # префикс для оповещений об ошибках и необработанных исключениях


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'taggit.apps.TaggitAppConfig',
    'web.apps.WebConfig',


]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'dicquo.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [BASE_DIR / 'templates'],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'dicquo.wsgi.application'


# Password validation
# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator', },
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator', },
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator', },
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator', },
]


# Internationalization
# https://docs.djangoproject.com/en/3.1/topics/i18n/
LANGUAGE_CODE = 'ru-RU'         # <--------- RUSSIAN
# TIME_ZONE = 'Europe/Moscow'     #
TIME_ZONE = 'America/Los_Angeles'     #
USE_I18N = True
USE_L10N = True
USE_TZ = True               # учитывать часовой пояс
FIRST_DAY_OF_WEEK = 1       # неделя начинается с понедельника
# APPEND_SLASH = False


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.1/howto/static-files/

STATIC_URL = '/static/'
MEDIA_URL = '/media/'

# Настройки для прода....
TOUCH_RELOAD = MY_TOUCH_RELOAD_PROD   # дёргаем этот файл, чтобы перегрузить uWSGI
MEDIA_ROOT = MY_MEDIA_ROOT_PROD
STATIC_ROOT = MY_STATIC_ROOT_PROD
STATIC_BASE_PATH = STATIC_ROOT
# DB_HOST = 'localhost'

if DEBUG:     # DEBUG: заменяем настройки прода, на настройки девопа
    if socket.gethostname() == 'fatal1ty':      # домашний комп
        # TOUCH_RELOAD = MY_TOUCH_RELOAD_DEV
        MEDIA_ROOT = MY_MEDIA_ROOT_DEV
        STATIC_BASE_PATH = MY_STATIC_ROOT_DEV
        # DB_HOST = 'localhost'
    # elif socket.gethostname() == 'SEremin2':    # офисный комп
    #     TOUCH_RELOAD = 'W:/!mail.ru_cloud/PRJ/PRJ Favicons/logs/favicon_prj_reload.log'
    #     MEDIA_ROOT = 'W:/!mail.ru_cloud/PRJ/PRJ Favicons/public/media'
    #     STATIC_BASE_PATH = 'W:/!mail.ru_cloud/PRJ/PRJ Favicons/public/static'
    #     DB_HOST = '10.10.5.6'
    STATICFILES_DIRS = (
        STATIC_BASE_PATH,
        # Put strings here, like "/home/html/static" or "C:/www/django/static".
        # Always use forward slashes, even on Windows.
        # Don't forget to use absolute paths, not relative paths.
        STATIC_BASE_PATH + '/js',
        STATIC_BASE_PATH + '/img',
        STATIC_BASE_PATH + '/fonts',
        STATIC_BASE_PATH + '/css',
        STATIC_BASE_PATH + '/svgs',
    )

# Database
# https://docs.djangoproject.com/en/3.1/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
        # 'NAME': 'db.sqlite3',
    }
}